import { type Translation, type TranslationLocale } from './translations';
export interface OpenAPIClientContext {
    /**
     * The translation language to use.
     */
    translation: Translation;
    /**
     * Icons used in the block.
     */
    icons: {
        chevronDown: React.ReactNode;
        chevronRight: React.ReactNode;
        plus: React.ReactNode;
    };
    /**
     * Force all sections to be opened by default.
     * @default false
     */
    defaultInteractiveOpened?: boolean;
    /**
     * The key of the block
     */
    blockKey?: string;
    /**
     * Optional id attached to the heading and used as an anchor.
     */
    id?: string;
    /**
     * Mark the context as a client context.
     */
    $$isClientContext$$: true;
}
export interface OpenAPIContext extends Omit<OpenAPIClientContext, '$$isClientContext$$'> {
    /**
     * Render a code block.
     */
    renderCodeBlock: (props: {
        code: string;
        syntax: string;
    }) => React.ReactNode;
    /**
     * Render the heading of the operation.
     */
    renderHeading: (props: {
        deprecated: boolean;
        title: string;
        stability?: string;
    }) => React.ReactNode;
    /**
     * Render the document of the operation.
     */
    renderDocument: (props: {
        document: object;
    }) => React.ReactNode;
    /**
     * Specification URL.
     */
    specUrl: string;
}
export type OpenAPIUniversalContext = OpenAPIClientContext | OpenAPIContext;
export interface OpenAPIContextInput extends Omit<OpenAPIContext, 'translation'> {
    /**
     * The translation language to use.
     * @default 'en'
     */
    locale?: TranslationLocale | undefined;
}
/**
 * Resolve OpenAPI context from the input.
 */
export declare function resolveOpenAPIContext(context: OpenAPIContextInput): OpenAPIContext;
/**
 * Get the client context from the OpenAPI context.
 */
export declare function getOpenAPIClientContext(context: OpenAPIUniversalContext): OpenAPIClientContext;
