import type { AnyObject, OpenAPIV3, OpenAPIV3_1 } from '@gitbook/openapi-parser';
import type { OpenAPIUniversalContext } from './context';
export declare function checkIsReference(input: unknown): input is OpenAPIV3.ReferenceObject;
export declare function createStateKey(key: string, scope?: string): string;
/**
 * Resolve the description of an object.
 */
export declare function resolveDescription(object: OpenAPIV3.SchemaObject | AnyObject): string | undefined;
/**
 * Extract descriptions from an object.
 */
export declare function extractDescriptions(object: AnyObject): {
    description: any;
    'x-gitbook-description-html': any;
};
/**
 * Resolve the first example from an object.
 */
export declare function resolveFirstExample(object: AnyObject): string | undefined;
/**
 * Resolve the schema of a parameter.
 * Extract the description, example and deprecated from parameter.
 */
export declare function resolveParameterSchema(parameter: OpenAPIV3.ParameterBaseObject): OpenAPIV3.SchemaObject;
/**
 * Transform a parameter object to a property object.
 */
export declare function parameterToProperty(parameter: OpenAPIV3.ParameterObject | OpenAPIV3.ReferenceObject | OpenAPIV3_1.ReferenceObject): {
    propertyName: string | undefined;
    schema: OpenAPIV3.SchemaObject;
    required: boolean | undefined;
};
/**
 * Get the class name for a status code.
 * 1xx: informational
 * 2xx: success
 * 3xx: redirect
 * 4xx, 5xx: error
 */
export declare function getStatusCodeClassName(statusCode: number | string): string;
/**
 * Get a default label for a status code.
 * This is used when there is no label provided in the OpenAPI spec.
 * 1xx: Information
 * 2xx: Success
 * 3xx: Redirect
 * 4xx, 5xx: Error
 */
export declare function getStatusCodeDefaultLabel(statusCode: number | string, context: OpenAPIUniversalContext): string;
